@@ -1,5 +1,6 @@
 # django imports
 from django.db import IntegrityError
+from django.db.models import Q
 from django.contrib.auth.models import User
 from django.contrib.auth.models import Group
 from django.contrib.contenttypes.models import ContentType
@@ -223,8 +224,93 @@ def get_local_roles(obj, principal):
         return [prr.role for prr in PrincipalRoleRelation.objects.filter(
             group=principal, content_id=obj.id, content_type=ctype)]
 
+def has_role(principal, role, obj=None):
+    """Returns True if the passed principal has passed role. If an object is
+    passed local roles will also taking into account.
+
+    **Parameters:**
+
+    principal
+        The principal (user or group) for which the roles are checked.
+
+    role
+        The role which is checked. Either the role name or the Role instance.
+
+    obj
+        The object for which the role is checked
+    """
+    if isinstance(role, str):
+        role = Role.objects.get(name=role)
+
+    roles = get_roles(principal, obj)
+    return role in roles
+
+def has_local_role(principal, role, obj):
+    """Returns True if the passed principal has the passed role for passed
+    object.
+
+    **Parameters:**
+
+    principal
+        The principal (user or group) for which the roles are checked.
+
+    role
+        The role which is checked. Either the role name or the Role instance.
+
+    obj
+        The object for which the role is checked
+    """
+    if isinstance(role, str):
+        role = Role.objects.get(name=role)
+
+    roles = get_local_roles(obj, principal)
+    return role in roles
+
+def has_global_role(principal, role):
+    """Returns True if the passed principal has the global role for passed
+    object.
+    
+    **Parameters:**
+
+    principal
+        The principal (user or group) for which the roles are checked.
+
+    role
+        The role which is checked. Either the role name or the Role instance.
+
+    obj
+        The object for which the role is checked
+    """
+    if isinstance(role, str):
+        role = Role.objects.get(name=role)
+
+    roles = get_roles(principal)
+    return role in roles
+
 # Permissions ################################################################
 
+def check_permission(obj, user, permission, roles=None):
+    """Checks whether passed user has passed permission for passed obj.
+
+    **Parameters:**
+
+    obj
+        The object for which the permission should be checked.
+
+    codename
+        The permission's codename which should be checked.
+
+    user
+        The user for which the permission should be checked.
+
+    roles
+        If given these roles will be assigned to the user temporarily before
+        the permissions are checked.
+    """
+    if not has_permission(obj, user, permission):
+        raise Unauthorized("User '%s' doesn't have permission '%s' for object '%s' (%s)"
+            % (user, codename, obj.slug, obj.__class__.__name__))
+
 def grant_permission(obj, role, permission):
     """Grants passed permission to passed role. Returns True if the permission
     was able to be added, otherwise False.
@@ -461,18 +547,20 @@ def register_permission(name, codename, ctypes=[]):
             identify the permission.
         content_types
             The content type for which the permission is active. This can be
-            used to display only reasonable permissions for an object. This 
+            used to display only reasonable permissions for an object. This
             must be a Django ContentType
     """
-    try:
-        p = Permission.objects.create(name=name, codename=codename)
-
-        ctypes = [ContentType.objects.get_for_model(ctype) for ctype in ctypes]
-        if ctypes:
-            p.content_types = ctypes
-            p.save()
-    except IntegrityError:
+    # Permission with same codename and/or name must not exist.
+    if Permission.objects.filter(Q(name=name) | Q(codename=codename)):
         return False
+
+    p = Permission.objects.create(name=name, codename=codename)
+
+    ctypes = [ContentType.objects.get_for_model(ctype) for ctype in ctypes]
+    if ctypes:
+        p.content_types = ctypes
+        p.save()
+
     return p
 
 def unregister_permission(codename):
@@ -498,12 +586,12 @@ def register_role(name):
 
     name
         The unique role name.
-    """
-    try:
-        role = Role.objects.create(name=name)
-    except IntegrityError:
+    """    
+    role, created = Role.objects.get_or_create(name=name)
+    if created:
+        return role
+    else:
         return False
-    return role
 
 def unregister_role(name):
     """Unregisters the role with passed name.
@@ -532,11 +620,11 @@ def register_group(name):
     name
         The unique group name.
     """
-    try:
-        group = Group.objects.create(name=name)
-    except IntegrityError:
+    group, created = Group.objects.get_or_create(name=name)
+    if created:
+        return group
+    else:
         return False
-    return group
 
 def unregister_group(name):
     """Unregisters the group with passed name. Returns True if the
